@@ -2106,7 +2106,7 @@ int AGUIX::openIM()
 
     destCB.callback = AGUIX_im_dest_callback;
     destCB.client_data = (XPointer)this;
-    if ( XSetIMValues( inputmethod, XNDestroyCallback, &destCB, NULL ) != NULL ) {
+    if ( XSetIMValues( inputmethod, XNDestroyCallback, &destCB, (void*)NULL ) != NULL ) {
       fprintf( stderr, "Worker Warning: Couldn't set IM destroy callback\n" );
     }
 #endif
@@ -2117,7 +2117,7 @@ int AGUIX::openIM()
        are not supported and dead keys will be loockuped to their normal character
     */
     supported_styles = XIMPreeditNothing | XIMStatusNothing;
-    XGetIMValues( inputmethod, XNQueryInputStyle, &im_supported_styles, NULL );
+    XGetIMValues( inputmethod, XNQueryInputStyle, &im_supported_styles, (void*)NULL );
     im_style = 0;
     for ( i = 0; i < im_supported_styles->count_styles; i++ ) {
       style = im_supported_styles->supported_styles[i];
