@@ -66,9 +66,7 @@ AGUIX *AWindow::getAGUIX() const
 
 void AWindow::sizeChanged(int width,int height)
 {
-#if 0
-  if((width!=w)||(height!=h)) {
-#endif
+  if ( width != _w || height != _h ) {
     AGMessage *agmsg = AGUIX_allocAGMessage();
     agmsg->type=AG_SIZECHANGED;
     agmsg->size.window=win;
@@ -81,9 +79,7 @@ void AWindow::sizeChanged(int width,int height)
       container->resize( _w, _h );
       container->rearrange();
     }
-#if 0
   }
-#endif
 }
 
 void AWindow::redraw()
@@ -465,7 +461,7 @@ void AWindow::resize(int nw,int nh)
       }
 
       XResizeWindow(dsp,win,nw,nh);
-#if 1
+#if 0
       // it's possible to not call sizeChanged here
       // but the size has to be stored so if one use
       // this case, the test in sizeChanged for different size
