@@ -1,6 +1,6 @@
 /* cyclebutton.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2007,2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -61,6 +61,9 @@ public:
   virtual bool isType(const char *type) const;
   void setOption(int index);
   int getMaxSize() const;
+
+  int getNrOfOptions() const;
+  void removeOption( int o );
 protected:
   std::vector<std::string> options;
   int act_opt;
@@ -76,3 +79,7 @@ protected:
 };
 
 #endif
+
+/* Local Variables: */
+/* mode:c++ */
+/* End: */
