@@ -125,7 +125,7 @@ public:
   int maximizeX();
   int maximizeY();
 
-  void showRow( int row );
+  void showRow( int row, bool redraw = true);
   
   void setData( int row, int ndata );
   int getData( int row ) const;
@@ -183,6 +183,7 @@ public:
   ColorDef getColor( int row ) const;
 
   void simpleRedrawUpdatedRows();
+  void timeLimitedRedraw();
 protected:
   int fields;
   int *fieldwidth;
@@ -359,6 +360,7 @@ protected:
 
   std::set<int> m_updated_rows;
   bool m_complete_update;
+  struct timeval m_last_update_time;
 };
 
 #endif
