@@ -19,9 +19,9 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "popupmenu.hh"
 #include <iostream>
 #include <stdlib.h>
-#include "popupmenu.hh"
 #include "drawablecont.hh"
 #include "utf8.hh"
 #include <stdexcept>
@@ -57,6 +57,8 @@ PopUpMenu::PopUpMenu( AGUIX *parent,
         e.name = it1->name;
         e.type = it1->type;
         e.id = it1->id;
+        e.fg = it1->fg;
+        e.bg = it1->bg;
 
         if ( it1->type == SUBMENU && it1->submenu != NULL ) {
             e.submenu = new PopUpMenu( parent, *(it1->submenu), getGroupID() );
@@ -495,7 +497,7 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
               break;
           case UnmapNotify:
           case FocusOut:
-              _aguix->hidePopUpWindows( getGroupID() );
+              hide();
               break;
           default:
               break;
@@ -515,7 +517,9 @@ PopUpMenu::InternPopUpEntry::InternPopUpEntry() : name( "" ),
                                                   id( -1 ),
                                                   submenu( NULL ),
                                                   y( 0 ),
-                                                  height( 0 )
+                                                  height( 0 ),
+                                                  fg( -1 ),
+                                                  bg( -1 )
 {
 }
 
@@ -526,7 +530,9 @@ PopUpMenu::InternPopUpEntry::~InternPopUpEntry()
 PopUpMenu::PopUpEntry::PopUpEntry() : name( "" ),
                                       type( NORMAL ),
                                       id( -1 ),
-                                      submenu( NULL )
+                                      submenu( NULL ),
+                                      fg( -1 ),
+                                      bg( -1 )
 {
 }
 
@@ -597,8 +603,8 @@ void PopUpMenu::sendMessage( const PopUpMenu *submenu, const std::list<int> &ent
     } else {
         AGMessage *agmsg = AGUIX_allocAGMessage();
         agmsg->popupmenu.menu = this;
-        agmsg->popupmenu.recursive_ids = new std::list<int>( entries );
-        agmsg->popupmenu.clicked_entry_id = entries.back();
+        agmsg->popupmenu.recursive_ids = new std::list<int>( new_entries );
+        agmsg->popupmenu.clicked_entry_id = new_entries.back();
         agmsg->type = AG_POPUPMENU_CLICKED;
         _aguix->putAGMsg( agmsg );
     }
@@ -613,16 +619,29 @@ void PopUpMenu::redrawEntry( int entry, int top_y )
 {
     if ( entry >= 0 && entry < (int)m_entries.size() ) {
         DrawableCont dc( _aguix, win );
+        int normal_fg, normal_bg;
+
+        if ( m_entries[entry].fg >= 0 ) {
+            normal_fg = m_entries[entry].fg;
+        } else {
+            normal_fg = 1;
+        }
+        if ( m_entries[entry].bg >= 0 ) {
+            normal_bg = m_entries[entry].bg;
+        } else {
+            normal_bg = 0;
+        }
 
         switch ( m_entries[entry].type ) {
             case HEADER:
                 _aguix->DrawText( dc, m_entries[entry].name.c_str(),
                                   getBorderWidth() + 1,
                                   top_y + 1,
-                                  1 );
+                                  normal_fg );
                 break;
             case NORMAL:
             case SUBMENU:
+            case GREYED_OUT:
                 if ( m_highlighted_entry == entry ) {
                     _aguix->drawBorder( win, true,
                                         getBorderWidth(),
@@ -630,11 +649,26 @@ void PopUpMenu::redrawEntry( int entry, int top_y )
                                         getWidth() - 2 * getBorderWidth(),
                                         getEntryHeight( entry ), 0 );
                 }
+                
+                if ( normal_bg != 0 ) {
+                    _aguix->setFG( normal_bg );
+                    _aguix->FillRectangle( win,
+                                           getBorderWidth() + 1,
+                                           top_y + 1,
+                                           getWidth() - 2 * getBorderWidth() - 2,
+                                           getEntryHeight( entry ) - 2 );
+                }
+
                 if ( isVisibleEntry( entry ) == true ) {
+                    int hfg = 2;
+
+                    if ( normal_bg == hfg ) {
+                        hfg = normal_fg;
+                    }
                     _aguix->DrawText( dc, m_entries[entry].name.c_str(),
                                       getBorderWidth() + 1,
                                       top_y + 1,
-                                      ( m_highlighted_entry == entry ) ? 2 : 1 );
+                                      ( m_highlighted_entry == entry ) ? hfg : normal_fg );
                 } else {
                     _aguix->DrawText( dc, m_entries[entry].name.c_str(),
                                       getBorderWidth() + 1 + 1,
@@ -697,6 +731,7 @@ void PopUpMenu::calcEntryDimensions()
         switch ( it1->type ) {
             case NORMAL:
             case SUBMENU:
+            case GREYED_OUT:
                 it1->height = _aguix->getCharHeight() + 2;
                 break;
             case HEADER:
@@ -770,6 +805,8 @@ void PopUpMenu::updateInfixFilter()
 bool PopUpMenu::isVisibleEntry( int pos ) const
 {
     if ( pos >= 0 && pos < (int)m_entries.size() ) {
+        if ( m_entries[pos].type == GREYED_OUT ) return false;
+
         std::string lower_infix = AGUIXUtils::tolower( m_infix_filter );
         std::string lower_name = AGUIXUtils::tolower( m_entries[pos].name );
         
