@@ -1,6 +1,6 @@
 /* textview.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2005-2007 Ralf Hoffmann.
+ * Copyright (C) 2005-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef TEXTVIEW_H
@@ -87,15 +87,34 @@ public:
 
     void setHighlightedBG( int col );
     int getHighlightedBG() const;
+
+    void setSelectionFG( int col );
+    int getSelectionFG() const;
+
+    void setSelectionBG( int col );
+    int getSelectionBG() const;
   private:
     int _background, _textcolor;
     int _highlighted_fg, _highlighted_bg;
+    int _selection_fg, _selection_bg;
   };
 
   void setColors( const ColorDef &col );
   ColorDef getColors() const;
 
   void textStorageChanged();
+
+  void setSelectionStart( int unwrapped_line_nr, int offset );
+  void getSelectionStart( int &unwrapped_line_nr, int &offset ) const;
+  void setSelectionEnd( int unwrapped_line_nr, int offset );
+  void getSelectionEnd( int &unwrapped_line_nr, int &offset ) const;
+  void clearSelection();
+
+  void sizeChanged( int width, int height );
+
+  void makeSelectionVisible();
+
+  int getYOffset();
 protected:
   class AContainer *cont;
   Slider *hbar, *vbar;
@@ -115,6 +134,15 @@ protected:
   } _highlight_line;
 
   ColorDef _colors;
+
+  struct {
+      int start_uline;
+      int start_offset;
+      int end_uline;
+      int end_offset;
+  } m_selection;
+
+  Pixmap m_buffer;
   
   void boxRedraw();
   void createContainer();
@@ -131,6 +159,15 @@ protected:
   void initColors();
 
   void updateHBarForVisibleLines();
+
+  void drawLineNumbers( int start_x, int end_x, int start_y, int lines );
+  void drawLines( int start_x, int start_y, int width, int lines );
+
+  void drawBuffer();
+  void drawBuffer( int dx, int dy, int dw, int dh );
+  void updateBuffer();
+
+  void checkBuffer();
 };
 
 #endif
