@@ -41,7 +41,8 @@ BookmarkDB::~BookmarkDB()
 
 int BookmarkDB::read()
 {
-    FILE *fp;
+    FILE *fp = NULL;
+    std::list< BookmarkDBEntry > loaded_entries;
         
     try {
         fp = worker_fopen( m_filename.c_str(), "r" );
@@ -49,66 +50,103 @@ int BookmarkDB::read()
         if ( fp == NULL )
             throw 3;
             
-        _entries.clear();
-
         bmdbrestart( fp );
         bmdb_readtoken();
-                
-        match( BMDB_BOOKMARKS );
-        match( '{' );
-                
-        while ( bmdb_token == BMDB_ENTRY ) {
-            match( BMDB_ENTRY );
+        
+        if ( bmdb_token == BMDB_BOOKMARKS ) {
+            match( BMDB_BOOKMARKS );
             match( '{' );
-                    
-            BookmarkDBEntry fbe( "", "" );
-            for (;;) {
-                if ( bmdb_token == BMDB_NAME ) {
-                    match( BMDB_NAME );
-                    match( '=' );
-                    if ( bmdb_token == BMDB_STRING ) {
-                        fbe.setName( bmdb_token_str );
-                    }
-                    match( BMDB_STRING );
-                    match( ';' );
-                } else if ( bmdb_token == BMDB_ALIAS ) {
-                    match( BMDB_ALIAS );
-                    match( '=' );
-                    if ( bmdb_token == BMDB_STRING ) {
-                        fbe.setAlias( bmdb_token_str );
-                    }
-                    match( BMDB_STRING );
-                    match( ';' );
-                } else if ( bmdb_token == BMDB_USEPARENT ) {
-                    match( BMDB_USEPARENT );
-                    match( '=' );
-                    if ( bmdb_token == BMDB_TRUE ) {
-                        fbe.setUseParent( true );
-                        match( BMDB_TRUE );
-                    } else if ( bmdb_token == BMDB_FALSE ) {
-                        fbe.setUseParent( false );
-                        match( BMDB_FALSE );
+            
+            while ( bmdb_token == BMDB_ENTRY ) {
+                match( BMDB_ENTRY );
+                match( '{' );
+                
+                BookmarkDBEntry fbe( "", "" );
+                for (;;) {
+                    if ( bmdb_token == BMDB_NAME ) {
+                        match( BMDB_NAME );
+                        match( '=' );
+                        if ( bmdb_token == BMDB_STRING ) {
+                            fbe.setName( bmdb_token_str );
+                        }
+                        match( BMDB_STRING );
+                        match( ';' );
+                    } else if ( bmdb_token == BMDB_ALIAS ) {
+                        match( BMDB_ALIAS );
+                        match( '=' );
+                        if ( bmdb_token == BMDB_STRING ) {
+                            fbe.setAlias( bmdb_token_str );
+                        }
+                        match( BMDB_STRING );
+                        match( ';' );
+                    } else if ( bmdb_token == BMDB_USEPARENT ) {
+                        match( BMDB_USEPARENT );
+                        match( '=' );
+                        if ( bmdb_token == BMDB_TRUE ) {
+                            fbe.setUseParent( true );
+                            match( BMDB_TRUE );
+                        } else if ( bmdb_token == BMDB_FALSE ) {
+                            fbe.setUseParent( false );
+                            match( BMDB_FALSE );
+                        } else {
+                            throw 1;
+                        }
+                        match( ';' );
+                    } else if ( bmdb_token == BMDB_CATEGORY ) {
+                        match( BMDB_CATEGORY );
+                        match( '=' );
+                        if ( bmdb_token == BMDB_STRING ) {
+                            fbe.setCategory( bmdb_token_str );
+                        }
+                        match( BMDB_STRING );
+                        match( ';' );
                     } else {
-                        throw 1;
+                        break;
                     }
-                    match( ';' );
-                } else {
-                    break;
                 }
+                match( '}' );
+                
+                loaded_entries.push_back( fbe );
             }
+            
             match( '}' );
-                    
-            _entries.push_back( fbe );
         }
-                
-        match( '}' );
-                
-        worker_fclose( fp );
-    } catch ( int ) {
-        std::cerr << "Error in line " << bmdb_linenr << " while parsing bookmarkdb config." << std::endl;
+        
+    } catch ( int e ) {
+        if ( e != 3 ) {
+            std::cerr << "Error in line " << bmdb_linenr << " while parsing bookmarkdb config." << std::endl;
+        }
+    }
+    if ( fp != NULL ) worker_fclose( fp );
+
+    bool same_bookmarks = true;
+    std::list< BookmarkDBEntry >::iterator old_it = _entries.begin();
+    std::list< BookmarkDBEntry >::iterator new_it = loaded_entries.begin();
+
+    for ( ;; ++new_it, ++old_it ) {
+        if ( old_it == _entries.end() && new_it == loaded_entries.end() ) break;
+
+        if ( old_it == _entries.end() ) {
+            same_bookmarks = false;
+            break;
+        }
+        if ( new_it == loaded_entries.end() ) {
+            same_bookmarks = false;
+            break;
+        }
+        
+        if ( new_it->equals( *old_it, true ) == false ) {
+            same_bookmarks = false;
+            break;
+        }
     }
 
-    return 0;
+    if ( same_bookmarks == false ) {
+        _entries = loaded_entries;
+        return 0;
+    } else {
+        return 1;
+    }
 }
 
 int BookmarkDB::write()
@@ -131,6 +169,10 @@ int BookmarkDB::write()
                 fh.configPutPairString( "alias", it1->getAlias().c_str() );
             }
             
+            if ( it1->getCategory().length() > 0 ) {
+                fh.configPutPairString( "category", it1->getCategory().c_str() );
+            }
+            
             fh.configCloseSection();
         }
 
@@ -168,8 +210,7 @@ std::list< BookmarkDBEntry> BookmarkDB::getEntries( const std::string &cat )
           it1 != _entries.end();
           it1++ ) {
         std::string c = it1->getCategory();
-        if ( c.length() < 1 ||
-             cat == "" ||
+        if ( cat == "" ||
              c == cat ) {
             matched_entries.push_back( *it1 );
         }
@@ -211,3 +252,18 @@ void BookmarkDB::updateEntry( const BookmarkDBEntry &entry,
         *it1 = newentry;
     }
 }
+
+std::auto_ptr<BookmarkDBEntry> BookmarkDB::getEntry( const std::string &name )
+{
+    std::auto_ptr<BookmarkDBEntry> res;
+
+    for ( entries_it it1 = _entries.begin();
+          it1 != _entries.end();
+          it1++ ) {
+        if ( it1->getName() == name ) {
+            res = std::auto_ptr<BookmarkDBEntry>( new BookmarkDBEntry( *it1 ) );
+            break;
+        }
+    }
+    return res;
+}
