@@ -345,21 +345,27 @@
      CHANGEFILTERS_WCP = 571,
      CHANGEBOOKMARKS_WCP = 572,
      QUERYLABEL_WCP = 573,
-     ERROR = 574,
-     ACTIVESIDE_WCP = 575,
-     SHOWFREESPACE_WCP = 576,
-     ACTIVEMODE_WCP = 577,
-     ASK_WCP = 578,
-     SSHALLOW_WCP = 579,
-     FIELD_WIDTH_WCP = 580,
-     QUICKSEARCHENABLED_WCP = 581,
-     FILTEREDSEARCHENABLED_WCP = 582,
-     XFTFONTS_WCP = 583,
-     USEMAGIC_WCP = 584,
-     MAGICPATTERN_WCP = 585,
-     MAGICCOMPRESSED_WCP = 586,
-     STRING_WCP = 587,
-     NUM_WCP = 588
+     MODIFYTABSOP_WCP = 574,
+     TABACTION_WCP = 575,
+     NEWTAB_WCP = 576,
+     CLOSECURRENTTAB_WCP = 577,
+     NEXTTAB_WCP = 578,
+     PREVTAB_WCP = 579,
+     ERROR = 580,
+     ACTIVESIDE_WCP = 581,
+     SHOWFREESPACE_WCP = 582,
+     ACTIVEMODE_WCP = 583,
+     ASK_WCP = 584,
+     SSHALLOW_WCP = 585,
+     FIELD_WIDTH_WCP = 586,
+     QUICKSEARCHENABLED_WCP = 587,
+     FILTEREDSEARCHENABLED_WCP = 588,
+     XFTFONTS_WCP = 589,
+     USEMAGIC_WCP = 590,
+     MAGICPATTERN_WCP = 591,
+     MAGICCOMPRESSED_WCP = 592,
+     STRING_WCP = 593,
+     NUM_WCP = 594
    };
 #endif
 /* Tokens.  */
@@ -679,21 +685,27 @@
 #define CHANGEFILTERS_WCP 571
 #define CHANGEBOOKMARKS_WCP 572
 #define QUERYLABEL_WCP 573
-#define ERROR 574
-#define ACTIVESIDE_WCP 575
-#define SHOWFREESPACE_WCP 576
-#define ACTIVEMODE_WCP 577
-#define ASK_WCP 578
-#define SSHALLOW_WCP 579
-#define FIELD_WIDTH_WCP 580
-#define QUICKSEARCHENABLED_WCP 581
-#define FILTEREDSEARCHENABLED_WCP 582
-#define XFTFONTS_WCP 583
-#define USEMAGIC_WCP 584
-#define MAGICPATTERN_WCP 585
-#define MAGICCOMPRESSED_WCP 586
-#define STRING_WCP 587
-#define NUM_WCP 588
+#define MODIFYTABSOP_WCP 574
+#define TABACTION_WCP 575
+#define NEWTAB_WCP 576
+#define CLOSECURRENTTAB_WCP 577
+#define NEXTTAB_WCP 578
+#define PREVTAB_WCP 579
+#define ERROR 580
+#define ACTIVESIDE_WCP 581
+#define SHOWFREESPACE_WCP 582
+#define ACTIVEMODE_WCP 583
+#define ASK_WCP 584
+#define SSHALLOW_WCP 585
+#define FIELD_WIDTH_WCP 586
+#define QUICKSEARCHENABLED_WCP 587
+#define FILTEREDSEARCHENABLED_WCP 588
+#define XFTFONTS_WCP 589
+#define USEMAGIC_WCP 590
+#define MAGICPATTERN_WCP 591
+#define MAGICCOMPRESSED_WCP 592
+#define STRING_WCP 593
+#define NUM_WCP 594
 
 
 
@@ -705,7 +717,7 @@ typedef union YYSTYPE {
   char *strptr;
 } YYSTYPE;
 /* Line 1403 of yacc.c.  */
-#line 709 "configparser.tab.h"
+#line 721 "configparser.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
