@@ -1,6 +1,6 @@
 /* configtokens.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2003-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2003-2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -350,7 +350,13 @@ struct mytoken tokenlist[]={
   { SET_WCP, "set" },
   { CHANGEFILTERS_WCP, "changefilters" },
   { CHANGEBOOKMARKS_WCP, "changebookmarks" },
-  { QUERYLABEL_WCP, "querylabel" }
+  { QUERYLABEL_WCP, "querylabel" },
+  { MODIFYTABSOP_WCP, "modifytabsop" },
+  { TABACTION_WCP, "tabaction" },
+  { NEWTAB_WCP, "newtab" },
+  { CLOSECURRENTTAB_WCP, "closecurrenttab" },
+  { NEXTTAB_WCP, "nexttab" },
+  { PREVTAB_WCP, "prevtab" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
