@@ -1,6 +1,6 @@
 /* dirbookmarkaddui.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2007-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,8 +29,9 @@
 #include "bookmarkdbentry.hh"
 #include "nwc_path.hh"
 #include "nwc_fsentry.hh"
+#include "bookmarkdbproxy.hh"
 
-DirBookmarkAddUI::DirBookmarkAddUI( AGUIX &aguix, BookmarkDB &data,
+DirBookmarkAddUI::DirBookmarkAddUI( AGUIX &aguix, BookmarkDBProxy &data,
                                     const std::string &dirname,
                                     const std::string &basename ) : m_aguix( aguix ),
                                                                     m_data( data ),
