@@ -25,14 +25,18 @@
 #include <aguix/text.h>
 #include <aguix/fieldlistview.h>
 #include <aguix/button.h>
+#include <aguix/solidbutton.h>
 #include "worker_locale.h"
 #include "bookmarkdbentry.hh"
 #include "bookmarkdbfilter.hh"
 #include "dirbookmarkaddui.hh"
 #include "dirbookmarkeditui.hh"
+#include "bookmarkdbproxy.hh"
+#include "nwc_path.hh"
+#include <algorithm>
 
-DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDB &data  ) : m_aguix( aguix ),
-                                                                  m_data( data )
+DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix( aguix ),
+                                                                       m_data( data )
 {
     m_filtered_data = std::auto_ptr<BookmarkDBFilter>( new BookmarkDBFilter( data ) );
 
@@ -42,30 +46,53 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDB &data  ) : m_aguix( aguix
                                                  0, catalog.getLocaleCom( 51 ) ) );
     m_win->create();
 
-    AContainer *co1 = m_win->setContainer( new AContainer( m_win.get(), 1, 4 ), true );
-    co1->setMaxSpace( 5 );
+    m_co1 = m_win->setContainer( new AContainer( m_win.get(), 1, 5 ), true );
+    m_co1->setMaxSpace( 5 );
     
-    AContainer *co1_2 = co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 0 );
+    AContainer *co1_2 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 0 );
     co1_2->setMaxSpace( 5 );
+    co1_2->setBorderWidth( 0 );
     co1_2->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 758 ), 1 ),
                 0, 0, AContainer::CFIX );
     m_infixtext = static_cast<Text*>( co1_2->add( new Text( &m_aguix, 0, 0, "", 1 ),
                                                   1, 0, AContainer::CINCW ) );
     
-    m_lv = static_cast<FieldListView*>( co1->add( new FieldListView( &m_aguix, 
+    AContainer *co1_5 = m_co1->add( new AContainer( m_win.get(), 3, 1 ), 0, 1 );
+    co1_5->setMaxSpace( 5 );
+    co1_5->setBorderWidth( 0 );
+    co1_5->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 822 ), 1 ),
+                0, 0, AContainer::CFIX );
+
+    AContainer *co1_5_1 = co1_5->add( new AContainer( m_win.get(), 3, 1 ), 1, 0 );
+    co1_5_1->setMaxSpace( 0 );
+    co1_5_1->setMinSpace( 0 );
+    co1_5_1->setBorderWidth( 0 );
+    m_prev_cat_b = (Button*)co1_5_1->add( new Button( &m_aguix, 0, 0,
+                                                      "<", 1, 0, 0 ), 0, 0, AContainer::CFIX );
+    m_cat_sb = dynamic_cast<SolidButton*>( co1_5_1->add( new SolidButton( &m_aguix, 0, 0,
+                                                                          "", 1, 0, true ), 1, 0, AContainer::CINCW ) );
+    m_next_cat_b = (Button*)co1_5_1->add( new Button( &m_aguix, 0, 0,
+                                                      ">", 1, 0, 0 ), 2, 0, AContainer::CFIX );
+    
+    m_lv = static_cast<FieldListView*>( m_co1->add( new FieldListView( &m_aguix, 
                                                                      0, 0, 
                                                                      400, 300, 0 ),
-                                                  0, 1, AContainer::CMIN ) );
-    m_lv->setNrOfFields( 2 );
+                                                  0, 2, AContainer::CMIN ) );
+    m_lv->setNrOfFields( 5 );
     m_lv->setShowHeader( true );
     m_lv->setFieldText( 0, catalog.getLocale( 809 ) );
-    m_lv->setFieldText( 1, catalog.getLocale( 810 ) );
+    m_lv->setFieldWidth( 1, 5 );
+    m_lv->setFieldTextMerged( 0, true );
+    m_lv->setFieldText( 2, catalog.getLocale( 810 ) );
+    m_lv->setFieldWidth( 3, 5 );
+    m_lv->setFieldTextMerged( 2, true );
+    m_lv->setFieldText( 4, catalog.getLocale( 823 ) );
     m_lv->setHBarState( 2 );
     m_lv->setVBarState( 2 );
     m_lv->setAcceptFocus( true );
     m_lv->setDisplayFocus( true );
 
-    AContainer *co1_4 = co1->add( new AContainer( m_win.get(), 3, 1 ), 0, 2 );
+    AContainer *co1_4 = m_co1->add( new AContainer( m_win.get(), 3, 1 ), 0, 3 );
     co1_4->setMinSpace( 5 );
     co1_4->setMaxSpace( -1 );
     co1_4->setBorderWidth( 0 );
@@ -94,7 +121,7 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDB &data  ) : m_aguix( aguix
                                               0,
                                               0 ), 2, 0, AContainer::CFIX );
 
-    AContainer *co1_3 = co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 3 );
+    AContainer *co1_3 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 4 );
     co1_3->setMinSpace( 5 );
     co1_3->setMaxSpace( -1 );
     co1_3->setBorderWidth( 0 );
@@ -123,13 +150,32 @@ DirBookmarkUI::~DirBookmarkUI()
 
 int DirBookmarkUI::mainLoop()
 {
-    m_win->show();
     showData( "" );
+
+    maximizeWin();
+    m_win->show();
+
     m_lv->takeFocus();
 
     std::string current_cat = "";
     AGMessage *msg;
     int endmode = 0;
+
+    updateCategoryText( current_cat );
+
+    {
+        std::string start_entry = NWC::Path::join( m_dirname,
+                                                   m_basename );
+        for ( int row = 0;; row++ ) {
+            if ( m_lv->isValidRow( row ) == false ) break;
+            if ( m_lv->getText( row, 0 ) == start_entry ) {
+                m_lv->setActiveRow( row );
+                m_lv->showActive();
+                break;
+            }
+        }
+    }
+
     for ( ; endmode == 0; ) {
         msg = m_aguix.WaitMessage( NULL );
         if ( msg != NULL ) {
@@ -175,6 +221,14 @@ int DirBookmarkUI::mainLoop()
                               showData( current_cat );
                           }
                       }
+                  } else if ( msg->button.button == m_prev_cat_b ) {
+                      current_cat = switchCat( current_cat, -1 );
+                      showData( current_cat );
+                      updateCategoryText( current_cat );
+                  } else if ( msg->button.button == m_next_cat_b ) {
+                      current_cat = switchCat( current_cat, 1 );
+                      showData( current_cat );
+                      updateCategoryText( current_cat );
                   }
                   break;
               case AG_KEYPRESSED:
@@ -196,7 +250,13 @@ int DirBookmarkUI::mainLoop()
                   } else if ( msg->key.key == XK_Escape ) {
                       endmode = -1;
                   } else if ( msg->key.key == XK_Left ) {
+                      current_cat = switchCat( current_cat, -1 );
+                      showData( current_cat );
+                      updateCategoryText( current_cat );
                   } else if ( msg->key.key == XK_Right ) {
+                      current_cat = switchCat( current_cat, 1 );
+                      showData( current_cat );
+                      updateCategoryText( current_cat );
                   } else if ( msg->key.key == XK_Up ) {
                   } else if ( msg->key.key == XK_Down ) {
                   } else if ( msg->key.key == XK_Next ) {
@@ -226,6 +286,43 @@ int DirBookmarkUI::mainLoop()
                       endmode = 1;
                   }
                   break;
+                case AG_FIELDLV_HEADERCLICKED:
+                    if ( ( msg->fieldlv.lv == m_lv ) &&
+                         ( msg->fieldlv.button == Button1 ) ) {
+                        // store current active entry
+                        BookmarkDBEntry active_entry = getActiveEntry( current_cat );
+
+                        // switch sort mode
+                        switch ( msg->fieldlv.row ) {
+                            case 0:
+                                m_filtered_data->toggleSortMode( BookmarkDBFilter::SORT_BY_NAME );
+                                showData( current_cat );
+                                break;
+                            case 2:
+                                m_filtered_data->toggleSortMode( BookmarkDBFilter::SORT_BY_ALIAS );
+                                showData( current_cat );
+                                break;
+                            case 4:
+                                m_filtered_data->toggleSortMode( BookmarkDBFilter::SORT_BY_CATEGORY );
+                                showData( current_cat );
+                                break;
+                            default:
+                                break;
+                        }
+
+                        // find previously stored entry and activate it
+                        std::list<BookmarkDBEntry> e = m_filtered_data->getEntries( current_cat );
+                        int row = 0;
+                        for ( std::list<BookmarkDBEntry>::iterator it1 = e.begin();
+                              it1 != e.end();
+                              it1++, row++ ) {
+                            if ( *it1 == active_entry ) {
+                                m_lv->setActiveRow( row );
+                                break;
+                            }
+                        }
+                    }
+                    break;
             }
             m_aguix.ReplyMessage( msg );
         }
@@ -266,7 +363,8 @@ void DirBookmarkUI::showData( const std::string &cat )
           it1++ ) {
         int row = m_lv->addRow();
         m_lv->setText( row, 0, it1->getName() );
-        m_lv->setText( row, 1, it1->getAlias() );
+        m_lv->setText( row, 2, it1->getAlias() );
+        m_lv->setText( row, 4, it1->getCategory() );
         m_lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
         
         if ( row == act_row )
@@ -319,3 +417,88 @@ BookmarkDBEntry DirBookmarkUI::getActiveEntry( const std::string &cat )
     }
     return dbe;
 }
+
+std::string DirBookmarkUI::switchCat( const std::string &current_cat, int dir )
+{
+    std::list<std::string> cats = m_data.getCats();
+    bool update = false;
+    std::string new_cat = current_cat;
+
+    if ( dir == 0 || cats.empty() == true ) return "";
+
+    if ( current_cat == "" ) {
+        // "all"
+        if ( dir > 0 ) {
+            new_cat = cats.front();
+            update = true;
+        } else {
+            new_cat = cats.back();
+            update = true;
+        }
+    } else {
+        std::list<std::string>::iterator it1 = std::find( cats.begin(),
+                                                          cats.end(),
+                                                          current_cat );
+
+        if ( it1 != cats.end() ) {
+            if ( dir < 0 ) {
+                // to the left
+                if ( it1 == cats.begin() )
+                    new_cat = "";
+                else {
+                    it1--;
+                    new_cat = *it1;;
+                }
+                update = true;
+            } else {
+                it1++;
+                if ( it1 == cats.end() )
+                    new_cat = "";
+                else
+                    new_cat = *it1;
+                update = true;
+            }
+        } else {
+            new_cat = "";
+            update = true;
+        }
+    }
+    return new_cat;
+}
+
+void DirBookmarkUI::updateCategoryText( const std::string &current_cat )
+{
+    if ( current_cat == "" ) {
+        m_cat_sb->setText( catalog.getLocale( 824 ) );
+    } else {
+        m_cat_sb->setText( current_cat.c_str() );
+    }
+}
+
+void DirBookmarkUI::maximizeWin()
+{
+    m_lv->maximizeX();
+    m_lv->maximizeY();
+    int my_w = m_lv->getWidth() + 10;
+    int my_h = m_lv->getHeight() + 10;
+
+    if ( my_w < 400 ) my_w = 400;
+    if ( my_h < 300 ) my_h = 300;
+
+    int mw = m_aguix.getRootWindowWidth() * 80 / 100;
+    int mh = m_aguix.getRootWindowHeight() * 80 / 100;
+    m_co1->resize( mw, mh );
+    m_co1->rearrange();
+
+    if ( my_w < m_lv->getWidth() ) {
+        m_co1->setMinWidth( my_w, 0, 2 );
+    } else {
+        m_co1->setMinWidth( m_lv->getWidth(), 0, 2 );
+    }
+    if ( my_h < m_lv->getHeight() ) {
+        m_co1->setMinHeight( my_h, 0, 2 );
+    } else {
+        m_co1->setMinHeight( m_lv->getHeight(), 0, 2 );
+    }
+    m_win->contMaximize( true );
+}
