@@ -1,6 +1,6 @@
 /* lister.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2005,2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: lister.cc,v 1.31 2005/10/17 19:07:45 ralf Exp $ */
 
 #include "lister.h"
 #include "worker.h"
@@ -27,6 +26,7 @@
 #include "wconfig.h"
 #include "configheader.h"
 #include "configparser.tab.h"
+#include <aguix/acontainer.h>
 
 Lister::Lister(Worker *tparent)
 {
@@ -34,11 +34,16 @@ Lister::Lister(Worker *tparent)
   aguix = parent->getAGUIX();
   win = parent->getListerWin( this );
 
-  w = win->getWidth();
-  h = win->getHeight();
-  if ( w < 50 ) w = 50;
-  if ( h < 50 ) h = 50;
-  lvb=(Button*)win->add(new Button(aguix,0,0,w,"","",1,1,0,0,1));
+  m_cont = win->setContainer( new AContainer( win, 1, 2 ), true );
+  m_cont->setBorderWidth( 0 );
+  m_cont->setMinSpace( 0 );
+  m_cont->setMaxSpace( 0 );
+  m_mode_cont = NULL;
+
+  lvb = (Button*)m_cont->add( new Button( aguix, 0, 0,
+                                          a_max( win->getWidth(), 50 ), "", "", 1, 1, 0, 0, 1 ),
+                              0, 0, AContainer::CINCW );
+  m_cont->setMinWidth( 50, 0, 0 );
   lvb->setAcceptFocus( false );
   aguix->Flush();
   activemode=NULL;
@@ -50,6 +55,8 @@ Lister::Lister(Worker *tparent)
     modes[i]=parent->getMode4ID(i,this);
   }
   timerclear( &lastlvbclick );
+
+  win->updateCont();
 }
 
 Lister::~Lister()
@@ -60,7 +67,8 @@ Lister::~Lister()
     delete modes[i];
   }
   delete [] modes;
-  delete win;
+  delete lvb;
+  delete m_cont;
 }
 
 void Lister::messageHandler(AGMessage *msg)
@@ -70,15 +78,6 @@ void Lister::messageHandler(AGMessage *msg)
   if(msg!=NULL) {
     switch(msg->type) {
       case AG_SIZECHANGED:
-        int bh, tw, th;
-        tw = win->getWidth();
-        th = win->getHeight();
-        if ( tw < 50 ) tw = 50;
-        if ( th < 50 ) th = 50;
-        bh=aguix->getCharHeight()+4;
-        lvb->resize(tw,bh);
-        this->w=tw;
-        this->h=th;
         break;
       case AG_BUTTONCLICKED:
         if(msg->button.button==lvb) {
@@ -128,8 +127,8 @@ void Lister::getGeometry(int *x2,int *y2,int *w2,int *h2)
   *x2=0;
   lvb->getSize(&tw,&th);
   *y2=th;
-  *w2=this->w;
-  *h2=this->h-th;
+  *w2 = m_cont->getWidth( 0, 1 );
+  *h2 = m_cont->getHeight( 0, 1 );
   if ( *h2 < 0 ) *h2 = 0;
 }
 
@@ -525,6 +524,11 @@ void  Lister::reconfig()
   lvb->setBG(0,bg);
   lvb->setFG(1,fg);
   lvb->setBG(1,bg);
+  lvb->resize( lvb->getWidth(), aguix->getCharHeight() + 4 );
+  m_cont->setMinHeight( lvb->getHeight(), 0, 0 );
+  m_cont->setMaxHeight( lvb->getHeight(), 0, 0 );
+  win->updateCont();
+
   if(activemode!=NULL) activemode->reconfig();
 }
 
@@ -543,3 +547,15 @@ bool Lister::startdnd(DNDMsg *dm)
   return (i<j)?true:false;
 }
 
+void Lister::setContainer( AContainer *mode_cont )
+{
+    if ( m_mode_cont != NULL ) {
+        m_cont->remove( m_mode_cont );
+        m_mode_cont = NULL;
+    }
+    if ( mode_cont != NULL ) {
+        m_cont->add( mode_cont, 0, 1 );
+        m_mode_cont = mode_cont;
+    }
+    win->updateCont();
+}
