@@ -1,6 +1,6 @@
 /* normalmode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -56,6 +56,8 @@ class NM_CopyOp_Dir;
 class NMCacheEntry;
 class DeleteOpWin;
 class FileEntry;
+class AContainer;
+class KarteiButton;
 
 struct NM_copyorder {
   char *destdir;
@@ -309,6 +311,11 @@ public:
 
     int queryLVDimensions( int &x, int &y,
                            int &w, int &h );
+
+    void newTab();
+    void closeCurrentTab();
+    void switchToTab( int tab );
+    void switchToTabDirection( int direction );
 protected:
   /*
    * NM_specialsourceInt always stores a pointer to a FE
@@ -327,7 +334,6 @@ protected:
     FileEntry *fe;  // element to copy
   };
 
-  void reconf( int nx, int ny, int nw, int nh, bool force = false );
   void buildListView();
   void deleteCache();
   void showcache(int);
@@ -370,9 +376,7 @@ protected:
   Button *hb[2], *parentb;
   StringGadget *sg;
   static const char *type;
-  int x,y,w,h;
   NMCacheEntry *ce;
-  int stored_cacheentry;
   List *cache;
   Requester *req;
   #define BUFSIZE 128*1024
@@ -738,6 +742,20 @@ protected:
     };
 
     PopUpSettings m_current_popup_settings;
+
+    AContainer *m_cont, *m_cont2, *m_tab_cont;
+    KarteiButton *m_tab_b;
+    Button *m_tab_new, *m_tab_close;
+
+    void updateTabs();
+    NMCacheEntry *findOldestCacheEntryNotInTab();
+
+    struct {
+        std::list<std::string> list_of_used_tabs;
+        int active_tab;
+    } m_off_store;
+
+    RefCount<TextShrinker> m_shrinker;
 };
 
 class NMFieldListViewDND:public FieldListViewDND
