@@ -1,6 +1,6 @@
 /* partspace.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2006,2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -42,8 +42,8 @@ public:
   loff_t getFreeSpace();
   loff_t getSpace();
   
-  loff_t getFreeSpaceH(char **unit_return);
-  loff_t getSpaceH(char **unit_return);
+  std::string getFreeSpaceH() const;
+  std::string getSpaceH() const;
 
   void slavehandler();
   
