@@ -1,5 +1,5 @@
 /* startprogop.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
+ * This file belongs to Worker, a file manager for UN*X/X11.
  * Copyright (C) 2001-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
@@ -31,6 +31,7 @@
 #include "wcfiletype.hh"
 #include "avfssupport.hh"
 #include "fileentry.hh"
+#include "nmspecialsourceext.hh"
 
 const char *StartProgOp::name="StartProgOp";
 
