@@ -1,5 +1,5 @@
 /* wconfig_colordef.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
+ * This file belongs to Worker, a file manager for UN*X/X11.
  * Copyright (C) 2006-2008 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
@@ -29,6 +29,26 @@ WConfig::ColorDef::ColorDef()
     setTextViewHighlightedBG( 2 );
     setTextViewSelectionFG( 2 );
     setTextViewSelectionBG( 1 );
+
+    label_colors_t c1;
+    c1.normal_fg = 4;
+    c1.normal_bg = 2;
+    c1.active_fg = 4;
+    c1.active_bg = 7;
+    addLabelColor( "marked", c1 );
+    addLabelColor( "1", c1 );
+
+    c1.normal_fg = 5;
+    c1.normal_bg = 2;
+    c1.active_fg = 5;
+    c1.active_bg = 7;
+    addLabelColor( "2", c1 );
+
+    c1.normal_fg = 6;
+    c1.normal_bg = 2;
+    c1.active_fg = 6;
+    c1.active_bg = 7;
+    addLabelColor( "3", c1 );
 }
     
 WConfig::ColorDef::~ColorDef()
@@ -44,6 +64,8 @@ WConfig::ColorDef &WConfig::ColorDef::operator=( const WConfig::ColorDef &other
         setTextViewHighlightedBG( other.getTextViewHighlightedBG() );
         setTextViewSelectionFG( other.getTextViewSelectionFG() );
         setTextViewSelectionBG( other.getTextViewSelectionBG() );
+
+        setLabelColors( other.getLabelColors() );
     }
     return *this;
 }
@@ -125,3 +147,33 @@ int WConfig::ColorDef::getTextViewSelectionBG() const
 {
     return _textview_colors.selectionbg;
 }
+
+void WConfig::ColorDef::setLabelColors( const std::map<std::string, label_colors_t> &cols )
+{
+    m_label_colors = cols;
+}
+
+const std::map<std::string, WConfig::ColorDef::label_colors_t> &WConfig::ColorDef::getLabelColors() const
+{
+    return m_label_colors;
+}
+
+const WConfig::ColorDef::label_colors_t &WConfig::ColorDef::getLabelColor( const std::string &label ) const
+{
+    std::map<std::string, WConfig::ColorDef::label_colors_t>::const_iterator it1;
+
+    it1 = m_label_colors.find( label );
+    if ( it1 != m_label_colors.end() ) return it1->second;
+    throw 1;
+}
+
+void WConfig::ColorDef::addLabelColor( const std::string &label,
+                                       const label_colors_t &col )
+{
+    m_label_colors[label] = col;
+}
+
+void WConfig::ColorDef::removeLabelColor( const std::string &label )
+{
+    m_label_colors.erase( label );
+}
