@@ -85,7 +85,7 @@ extern "C" {
 #ifdef HAVE_SYS_MOUNT_H
   #include <sys/mount.h>
 #endif
-#ifdef HAVE_SYS_SYSINFO_H
+#if defined HAVE_SYS_SYSINFO_H && defined HAVE_SYSINFO
   #include <sys/sysinfo.h>
 #endif
 
