@@ -1,6 +1,6 @@
 /* worker.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -1000,7 +1000,7 @@ void Worker::about()
   int erg;
   
   tstr = (char*)_allocsafe( 1024 + 3 * A_BYTESFORNUMBER( int ) + strlen( WORKER_COMMENT ) );
-  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2008 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
+  sprintf(tstr,"Worker %d.%d.%d%s|Copyright (C) 1998 - 2009 Ralf Hoffmann",WORKER_MAJOR,WORKER_MINOR,WORKER_PATCH,WORKER_COMMENT);
   str1 = tstr;
   _freesafe( tstr );
   
@@ -2406,6 +2406,11 @@ void Worker::closeMainWin()
   delete req_static;
   req_static = new Requester( aguix );
 
+  delete listerwin[0];
+  listerwin[0] = NULL;
+  delete listerwin[1];
+  listerwin[1] = NULL;
+
   if ( buttons != NULL ) {
     if ( ( curRows != 0 ) && ( curColumns != 0 ) ) {
       for ( i = 0; i < curRows; i++ ) {
