@@ -1,6 +1,6 @@
 /* worker_commands.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2007,2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -192,6 +192,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 55:
       fpr = new ChangeLabelOp();
       break;
+    case 56:
+      fpr = new ModifyTabsOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -257,6 +260,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( RunCustomAction::name ) == true ) type = 53;
   else if ( fpr->isName( OpenWorkerMenuOp::name ) == true ) type = 54;
   else if ( fpr->isName( ChangeLabelOp::name ) == true ) type = 55;
+  else if ( fpr->isName( ModifyTabsOp::name ) == true ) type = 56;
   return type;
 }
 
