@@ -1,6 +1,6 @@
 /* worker_locale.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2009 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,8 +24,8 @@
 #include "worker.h"
 #include <aguix/utf8.hh>
 
-#define CATENTRY 851
-#define CATCOMENTRY 56
+#define CATENTRY 861
+#define CATCOMENTRY 57
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -630,8 +630,7 @@ The default value here is the active entry and it's already correctly protected!
   catalog[563]=dupstring( "Buttons, list views" );
   catalog[564]=dupstring( "List views, Buttons" );
   catalog[565]=dupstring( "Select button and list view orientation:" );
-  catalog[566]=dupstring( "Select the positions of the elements;|Select two elements with\
- a position to swap,|doubleclick to remove position:" );
+  catalog[566]=dupstring( "" );
   catalog[567]=dupstring( "Buttons vertical" );
   catalog[568]=dupstring( "List views vertical" );
   catalog[569]=dupstring( "Layout configuration" );
@@ -951,6 +950,16 @@ match any font." );
   catalog[848]=dupstring( "Show bookmarks with empty label" );
   catalog[849]=dupstring( " - %s/%s free" );
   catalog[850]=dupstring( "Query label on runtime" );
+  catalog[851]=dupstring( "Tab action" );
+  catalog[852]=dupstring( "New tab" );
+  catalog[853]=dupstring( "Close current tab" );
+  catalog[854]=dupstring( "Switch to next tab" );
+  catalog[855]=dupstring( "Switch to prev tab" );
+  catalog[856]=dupstring( "Select the order of the elements.|An example view is shown at the right hande side.|Keep the list empty to use default view." );
+  catalog[857]=dupstring( "Available elements:" );
+  catalog[858]=dupstring( "Used elements:" );
+  catalog[859]=dupstring( "Add element" );
+  catalog[860]=dupstring( "Remove element" );
 
 //  catalog[]=dupstring( "" );
   
@@ -1010,6 +1019,7 @@ match any font." );
   catalogcom[53]=dupstring( "Run custom action" );
   catalogcom[54]=dupstring( "Open Worker menu" );
   catalogcom[55]=dupstring( "Change file label" );
+  catalogcom[56]=dupstring( "Modify tabs" );
   
   catalogflag[0]=dupstring( "Stringrequester" );
   catalogflag[1]=dupstring( "path" );
